@@ -46,9 +46,9 @@ class BaseServer:
             self.host, self.port, self.app
         )
         # Don't to log
-        log_request = httpd.RequestHandlerClass.log_request
-        no_logging = lambda *args, **kwargs: None
-        httpd.RequestHandlerClass.log_request = no_logging
+        # log_request = httpd.RequestHandlerClass.log_request
+        # no_logging = lambda *args, **kwargs: None
+        # httpd.RequestHandlerClass.log_request = no_logging
 
         self.ready.set()
         while True:
@@ -60,7 +60,7 @@ class BaseServer:
 
             if self.stop_read in ready:
                 os.read(self.stop_read, len(self.__stop_marker))
-                httpd.RequestHandlerClass.log_request = log_request
+                # httpd.RequestHandlerClass.log_request = log_request
                 break
 
 
@@ -120,7 +120,8 @@ class TestCase(unittest.TestCase):
             query_string = urllib.parse.urlencode(data)
             url = path+'?'+query_string
         else:
-            url = path
+            url = urllib.parse.quote(path)
+
         url = self.base_url+url
         res = {}
         f = open(os.devnull, 'w')
